--- src/tse3/Serializable.h.orig	2005-07-25 11:23:00 UTC
+++ src/tse3/Serializable.h
@@ -20,6 +20,7 @@
 #include <iosfwd>
 #include <iomanip>
 #include <cstddef>
+#include <iostream>
 
 namespace TSE3
 {
