--- src/McBopomofo.cpp.orig	2022-12-30 09:01:33 UTC
+++ src/McBopomofo.cpp
@@ -31,6 +31,7 @@
 #include <fmt/format.h>
 
 #include <memory>
+#include <sstream>
 #include <unordered_map>
 #include <utility>
 
