--- plugins/codecs/ndlz/xxhash.h.orig	2021-10-02 12:17:56 UTC
+++ plugins/codecs/ndlz/xxhash.h
@@ -2934,6 +2934,7 @@ enum XXH_VECTOR_TYPE /* fake enum */ {
 #    if defined(__GNUC__) && !defined(__APPLE_ALTIVEC__)
 #      define __APPLE_ALTIVEC__
 #    endif
+#    define vector __vector
 #    include <altivec.h>
 #  endif
 
