--- src/psi2.f~	Sat May 25 03:50:01 1991
+++ src/psi2.f	Tue Jan 16 13:40:36 2007
@@ -175,7 +175,7 @@
 C
       SUBROUTINE DRAMOL (C,NAT,IAN,TITLE,CO,THE,GAM,PHI,CM,PERZ,SCALE,
      *   INIT,IATSYM,IATSMN)
-      COMMON /MIN/ YMOLMN
+      COMMON /MINPSI88/ YMOLMN
       COMMON /BONDS/ NBND,IB,IC
       DIMENSION C(1024,3),IAN(60),IATSMN(60),CO(3),NCHAR1(18)
       DIMENSION IB(35),IC(35),BX(4),BY(4),COVRAD(18)
@@ -468,7 +468,7 @@
       COMMON /DLT/ YINT(75000),SLPINV(75000),PLANES(1024,3),NCHID
       COMMON /POINTS/ AC(75000,3)
       COMMON /HLCOM/ NAC,NBEG,ACMIN,ACMAX
-      COMMON /MIN/ YMOLMN
+      COMMON /MINPSI88/ YMOLMN
       COMMON /RPLOT/ N,CO(3),CM,THE,GAM,PHI,X(1024),Y(1024),Z(1024),
      *   IDASH,SCALE,PERZ
       CHARACTER*(*) SUBT
