--- src/libsphinx2/sc_vq.c.orig	2001-12-13 21:11:23 UTC
+++ src/libsphinx2/sc_vq.c
@@ -64,6 +64,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <assert.h>
 #include <limits.h>
 
