--- dynamics/tap_dynamics.c.orig	2016-01-25 10:55:48 UTC
+++ dynamics/tap_dynamics.c
@@ -267,7 +267,7 @@ rms_env_process(rms_env *r, const rms_t 
 
 
 
-inline
+
 float
 get_table_gain(int mode, float level) {
 
