--- src/dictionary.h.orig	2003-05-15 00:14:52 UTC
+++ src/dictionary.h
@@ -22,6 +22,7 @@ using namespace std;
 #include "../config.h"
 
 #include <string>
+#include <cstring>
 #include <vector>
 #include <time.h>
 #include <stdlib.h>
