--- tools/pdb_align_points.cc.orig	2019-01-29 07:00:56 UTC
+++ tools/pdb_align_points.cc
@@ -23,6 +23,7 @@
 #include <vector>
 #include <iterator>
 #include <fstream>
+#include <sstream>
 #include <dsrpdb/align.h>
 #include <dsrpdb/distance.h>
 
