--- src/DesignCompile/CompileExpression.cpp.orig	2022-09-09 21:42:55 UTC
+++ src/DesignCompile/CompileExpression.cpp
@@ -46,6 +46,7 @@
 
 #include <cmath>
 #include <cstring>
+#include <string>
 
 // UHDM
 #include <uhdm/ElaboratorListener.h>
