--- src/core/Sheet.cpp.orig	2019-05-16 08:08:50 UTC
+++ src/core/Sheet.cpp
@@ -397,7 +397,7 @@ int Sheet::prepare_export(ExportSpecification* spec)
 		m_rendering = true;
 	}
 
-	spec->startLocation = LONG_LONG_MAX;
+	spec->startLocation = LLONG_MAX;
 	spec->endLocation = TimeRef();
 
 	TimeRef endlocation, startlocation;
