--- rand.h.orig	2016-06-30 09:38:55.000000000 +0000
+++ rand.h	2016-10-18 20:04:31.159630423 +0000
@@ -1,11 +1,11 @@
 #ifndef RAND_H
 #define RAND_H
 
-using namespace std;
 #include "port.h"
 #include <string>
 #include <stdio.h>
 #include <stdlib.h>
+using namespace std;
 
 class Rand
 {
