--- apps/xsplay.cc.orig	2001-02-20 19:04:07 UTC
+++ apps/xsplay.cc
@@ -29,7 +29,7 @@
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
-#include <iostream.h>
+#include <iostream>
 #include <iomanip.h>
 
 #include "mpegsound.h"
