--- aksetup_helper.py.orig	2012-12-16 01:56:27 UTC
+++ aksetup_helper.py
@@ -1,6 +1,6 @@
 # dealings with ez_setup ------------------------------------------------------
-import distribute_setup
-distribute_setup.use_setuptools()
+#import distribute_setup
+#distribute_setup.use_setuptools()
 
 import setuptools
 from setuptools import Extension
