--- setup.py.orig	2020-06-25 14:36:51 UTC
+++ setup.py
@@ -35,7 +35,7 @@ setup(
         "cadquery.contrib",
         "cadquery.occ_impl",
         "cadquery.plugins",
-        "tests",
+        "cadquery.tests",
     ],
     include_package_data=True,
     zip_safe=False,
