--- src/libsphinx2fe/fe_sigproc.c.orig	2016-07-26 15:58:05 UTC
+++ src/libsphinx2fe/fe_sigproc.c
@@ -43,7 +43,7 @@
 
 #ifndef	M_PI
 #define M_PI	(3.14159265358979323846)
-#endif	M_PI
+#endif
 
 #define FORWARD_FFT 1
 #define INVERSE_FFT -1
