--- kent/src/inc/uuid.h.orig	2021-04-14 11:17:54 UTC
+++ kent/src/inc/uuid.h
@@ -5,7 +5,7 @@
  *
  * If you use this file you need to add -luuid to your link line. */
 
-#include <uuid/uuid.h>
+#include <uuid.h>
 
 #define UUID_STRING_SIZE 37
 
