--- rapid/plugin/x/ngs/include/ngs_common/protocol_protobuf.h.orig	2019-04-13 13:32:15 UTC
+++ rapid/plugin/x/ngs/include/ngs_common/protocol_protobuf.h
@@ -29,7 +29,6 @@
 #include <google/protobuf/io/tokenizer.h>
 #include <google/protobuf/io/zero_copy_stream.h>
 #include <google/protobuf/wire_format_lite.h>
-#include <google/protobuf/wire_format_lite_inl.h>
 #include <google/protobuf/dynamic_message.h>
 
 #include "mysqlx_connection.pb.h"
