--- svgui/layer/WaveformLayer.cpp.orig	2020-05-29 17:17:11 UTC
+++ svgui/layer/WaveformLayer.cpp
@@ -27,6 +27,7 @@
 #include "data/model/WaveformOversampler.h"
 
 #include <QPainter>
+#include <QPainterPath>
 #include <QPixmap>
 #include <QTextStream>
 
