--- include/id3/writers.h.orig	2003-03-02 00:23:00 UTC
+++ include/id3/writers.h
@@ -29,6 +29,7 @@
 #define _ID3LIB_WRITERS_H_
 
 #include "id3/writer.h"
+#include <cstring>
 #include "id3/id3lib_streams.h"
 //#include <string.h>
 
