--- awl/knob.h.orig	2020-05-18 18:30:06 UTC
+++ awl/knob.h
@@ -24,6 +24,7 @@
 #define __AWLKNOB_H__
 
 #include "aslider.h"
+#include <QPainterPath>
 // #include <QtDesigner/QDesignerExportWidget>
 
 namespace Awl {
