--- src/libsphinx2/r_agc_noise.c.orig	2001-12-13 21:11:23 UTC
+++ src/libsphinx2/r_agc_noise.c
@@ -34,6 +34,7 @@
  *
  */
 #include <stdio.h>
+#include <string.h>
 
 #include "s2types.h"
 #include "c.h"
