--- SpliceGraph.cpp.orig	2021-11-26 18:13:48 UTC
+++ SpliceGraph.cpp
@@ -1,7 +1,6 @@
 /*
  * Created by Fahimeh Mirhaj on 6/10/19.
 */
-using namespace std;
 
 #include "SpliceGraph.h"
 #include "GTF.h"
