--- eigen_func.h.orig	2016-06-22 03:11:01 UTC
+++ eigen_func.h
@@ -12,9 +12,9 @@
 #ifndef _EIGENFUNC_H
 #define _EIGENFUNC_H
 
-#ifndef EIGEN_USE_MKL_ALL
-#define EIGEN_USE_MKL_ALL
-#endif
+//#ifndef EIGEN_USE_MKL_ALL
+//#define EIGEN_USE_MKL_ALL
+//#endif
 
 #include "CommFunc.h"
 #include "StatFunc.h"
