--- src/Widget/QDropAreaWidget.cpp.orig	2020-05-21 08:16:02 UTC
+++ src/Widget/QDropAreaWidget.cpp
@@ -6,6 +6,7 @@
  */
 
 #include <QPainter>
+#include <QPainterPath>
 
 #include "QDropAreaWidget.h"
 
