--- GUI/Widgets/Fl_Knob.H.orig	Wed Mar 19 13:57:41 2003
+++ GUI/Widgets/Fl_Knob.H	Wed Mar 19 13:57:56 2003
@@ -4,6 +4,7 @@
 #define Fl_Knob_H
 #include <FL/Fl.H>
 #include <FL/Fl_Valuator.H>
+#include <FL/Fl_Group.H>
 
 class Fl_Knob : public Fl_Valuator {
 public:
