--- IMB_declare.h.orig	2016-07-27 14:58:51 UTC
+++ IMB_declare.h
@@ -69,7 +69,6 @@ For more documentation than found here, 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <malloc.h>
 #include <stddef.h>
 #include "IMB_appl_errors.h"
 #include "IMB_err_check.h"
