--- cura_app.py.orig	2020-02-28 16:06:57 UTC
+++ cura_app.py
@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.8
+#!/usr/bin/env %%PYTHON_CMD%%
 
 # Copyright (c) 2022 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
