--- include/gal/graphics_abstraction_layer.h.orig	2021-06-08 00:34:09 UTC
+++ include/gal/graphics_abstraction_layer.h
@@ -30,6 +30,7 @@
 #include <deque>
 #include <stack>
 #include <limits>
+#include <cmath>
 
 #include <math/matrix3x3.h>
 
