--- src/PYLibPinyin.cc.orig	2018-06-27 03:08:59 UTC
+++ src/PYLibPinyin.cc
@@ -21,6 +21,7 @@
 
 #include "PYLibPinyin.h"
 
+#include <stdio.h>
 #include <string.h>
 #include <pinyin.h>
 #include "PYPConfig.h"
