--- czech-lexicon.scm.orig	2006-06-21 07:32:07 UTC
+++ czech-lexicon.scm
@@ -263,3 +263,51 @@
 ("softwary" nil (((s o f t v e: r i) 0)))
 ("softwarů" nil (((s o f t v e: r u:) 0)))
 ("softwarům" nil (((s o f t v e: r u: m) 0)))
+("office" nil (((o f i s) 0)))
+("Firefox" nil (((f a j r f o k s) 0)))
+("Mozilla" nil (((m o z i l a) 0)))
+("OpenOffice" nil (((o p e n o f i s) 0)))
+("Orca" nil (((o r k a) 0)))
+("Orcy" nil (((o r k y) 0)))
+("Base" nil (((b e j z) 0)))
+("Calc" nil (((k o: l k) 0)))
+("Draw" nil (((d r o:) 0)))
+("Impress" nil (((i m p r e s) 0)))
+("Math" nil (((m a: f) 0)))
+("Writer" nil (((v r a j t r) 0)))
+("www" nil (((v e: v e: v e:) 0)))
+("WWW" nil (((v e: v e: v e:) 0)))
+("Einstein" nil (((a j n s~ t a j n) 0)))
+("Einsteina" nil (((a j n s~ t a j n a) 0)))
+("Einsteinovi" nil (((a j n s~ t a j n o v i) 0)))
+("Einsteinem" nil (((a j n s~ t a j n e m) 0)))
+("Einsteinova" nil (((a j n s~ t a j n o v a) 0)))
+("Einsteinovy" nil (((a j n s~ t a j n o v i) 0)))
+("Einsteinově" nil (((a j n s~ t a j n o v j e) 0)))
+("Einsteinovou" nil (((a j n s~ t a j n o v o u) 0)))
+("Newton" nil (((n~ u: t n) 0)))
+("Newtona" nil (((n~ u: t n a) 0)))
+("Newtonovi" nil (((n~ u: t n o v a) 0)))
+("Newtonem" nil (((n~ u: t n e m) 0)))
+("Newtonova" nil (((n~ u: t n o v a) 0)))
+("Newtonovy" nil (((n~ u: t n o v y) 0)))
+("Newtonově" nil (((n~ u: t n o v j e) 0)))
+("Newtonovou" nil (((n~ u: t n o v o u) 0)))
+("university" nil (((u n i v e r z i t y) 0)))
+("Maryland" nil (((m e r y l e n d) 0)))
+("Michigan" nil (((m i s~ i g e n) 0)))
+("technika" nil (((t e ch n i k a) 0)))
+("techniku" nil (((t e ch n i k u) 0)))
+("monitorovat" nil (((m o n i t o r o v a t) 0)))
+("monitoruji" nil (((m o n i t o r u j i) 0)))
+("monitoruješ" nil (((m o n i t o r u j e s~) 0)))
+("monitoruje" nil (((m o n i t o r u j e) 0)))
+("monitorujeme" nil (((m o n i t o r u j e m e) 0)))
+("monitorujete" nil (((m o n i t o r u j e t e) 0)))
+("monitorují" nil (((m o n i t o r u j i:) 0)))
+("Marsu" nil (((m a r z u) 0)))
+("Marsem" nil (((m a r z e m) 0)))
+("Marsovy" nil (((m a r z o v i) 0)))
+("Marsových" nil (((m a r z o v i: ch) 0)))
+("Marsovým" nil (((m a r z o v i: m) 0)))
+("Marsovými" nil (((m a r z o v i: m i) 0)))
