--- src/third_party/mozjs-60/platform/ppc64le/freebsd/build/js-confdefs.h.orig	2020-11-25 14:27:55 UTC
+++ src/third_party/mozjs-60/platform/ppc64le/freebsd/build/js-confdefs.h
@@ -0,0 +1,78 @@
+/* List of defines generated by configure. Included with preprocessor flag,
+ * -include, to avoid long list of -D defines on the compile command-line.
+ * Do not edit.
+ */
+
+#ifndef js_confdefs_h
+#define js_confdefs_h
+
+// Expands to all the defines from configure.
+#define CPP_THROW_NEW throw()
+#define CROSS_COMPILE 
+#define EDITLINE 1
+#define HAVE_64BIT_BUILD 1
+#define HAVE_CLOCK_MONOTONIC 1
+#define HAVE_CPP_DYNAMIC_CAST_TO_VOID_PTR 1
+#define HAVE_DIRENT_H 1
+#define HAVE_DLOPEN 1
+#define HAVE_GETC_UNLOCKED 1
+#define HAVE_GETOPT_H 1
+#define HAVE_GMTIME_R 1
+#define HAVE_INTTYPES_H 1
+#define HAVE_LANGINFO_CODESET 1
+#define HAVE_LIBM 1
+#define HAVE_LOCALECONV 1
+#define HAVE_LOCALTIME_R 1
+#define HAVE_MALLOC_H 1
+#define HAVE_MALLOC_USABLE_SIZE 1
+#define HAVE_MEMALIGN 1
+#define HAVE_NETINET_IN_H 1
+#define HAVE_NL_TYPES_H 1
+#define HAVE_POSIX_FADVISE 1
+#define HAVE_POSIX_FALLOCATE 1
+#define HAVE_POSIX_MEMALIGN 1
+#define HAVE_PTHREAD_GETNAME_NP 1
+#define HAVE_RES_NINIT 1
+#define HAVE_SINCOS 1
+#define HAVE_SSIZE_T 1
+#define HAVE_STDINT_H 1
+#define HAVE_STRNDUP 1
+#define HAVE_SYS_MOUNT_H 1
+#define HAVE_SYS_QUEUE_H 1
+#define HAVE_SYS_STATVFS_H 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_THREAD_TLS_KEYWORD 1
+#define HAVE_TM_ZONE_TM_GMTOFF 1
+#define HAVE_UNISTD_H 1
+#define HAVE_VALLOC 1
+#define HAVE_VA_COPY 1
+#define HAVE_VISIBILITY_ATTRIBUTE 1
+#define HAVE_VISIBILITY_HIDDEN_ATTRIBUTE 1
+#define HAVE___CXA_DEMANGLE 1
+#define JS_64BIT 1
+#define JS_CODEGEN_NONE 1
+#define JS_DEFAULT_JITREPORT_GRANULARITY 3
+#define JS_POSIX_NSPR 1
+#define JS_PUNBOX64 1
+#define JS_STANDALONE 1
+#define MALLOC_H <malloc.h>
+#define MALLOC_USABLE_SIZE_CONST_PTR const
+#define MOZILLA_UAVERSION "60.0"
+#define MOZILLA_VERSION "60.3.0"
+#define MOZILLA_VERSION_U 60.3.0
+#define MOZJS_MAJOR_VERSION 60
+#define MOZJS_MINOR_VERSION 3
+#define MOZ_BUILD_APP js
+#define MOZ_DLL_SUFFIX ".so"
+#define MOZ_UPDATE_CHANNEL default
+#define NO_NSPR_10_SUPPORT 1
+#define RELEASE_OR_BETA 1
+#define STDC_HEADERS 1
+#define VA_COPY va_copy
+#define XP_UNIX 1
+#define _REENTRANT 1
+#define _THREAD_SAFE 1
+
+#include "js/RequiredDefines.h"
+
+#endif /* js_confdefs_h */
