--- include/global.h.orig	2003-12-18 21:51:43 UTC
+++ include/global.h
@@ -57,7 +57,7 @@
 #endif
 #include <math.h>
 #include <stdarg.h>
-#include <wait.h>
+#include <sys/wait.h>
 #include <sys/mman.h>
 #include <sys/types.h>
 #include <sys/stat.h>
